@@ -302,6 +302,44 @@ def check_str(s: Any) -> str:
     return string
 #}}}
 
+
+#
+def strip_slash(input: str):
+    
+    """
+    The method ensures a slash is not at the end of a string.
+    :param intput:      The input string to check.
+    :type input:        str
+    :returns:           A string without a trailing "/".
+    :rtype:             str
+    """ 
+    
+    result = str(input)
+    
+    if result.endswith("/"):
+        result = result[:-1]
+        
+    return result
+
+#
+def strip_slash(input: str):
+    
+    """
+    The method ensures a slash is not at the end of a string.
+
+    :param intput:      The input string to check.
+    :type input:        str
+    :returns:           A string without a trailing "/".
+    :rtype:             str
+    """ 
+    
+    result = str(input)
+    
+    if result.endswith("/"):
+        result = result[:-1]
+        
+    return result
+
 #
 def ensure_slash(directory: str, 
                  position: int
@@ -348,10 +386,10 @@ def run_async_in_thread(func, *args, **kwargs):
 
     :param func:        The name of the function to run.
     :type func:         str
-    :param *args:       The arguments of the function.
-    :type *args:        
-    :param **kwargs:    The arguments of the function.
-    :type **kwargs:     
+    :param args:        The arguments of the function.
+    :type args:         args
+    :param kwargs:      The arguments of the function.
+    :type kwargs:       kwargs
     :returns:           the result of the execution of the thread
     :rtype:             AsyncThreadWrapper.result
     """ 
@@ -442,3 +480,83 @@ def ensure_protocol(host: str):
             return "http://" + strip_protocol(host)
         else:
             return "https://" + strip_protocol(host)
+
+#
+def get_tenant_id(client_id: str):
+    
+    """
+    Gets tenant id from client_id with 'saascore-', 'geospatial-' prefixes or without.
+
+    :param client_id: A client id for the authentication system.
+    :type client_id:  str
+    :returns:         The tenant id.
+    :rtype:           str
+    """ 
+    
+    tenant_id: str = None
+    
+    if client_id is not None:
+        tenant_id = client_id
+        if client_id.startswith('saascore-'):
+            tenant_id = client_id[9:len(client_id)]
+        elif client_id.startswith('geospatial-'):
+            tenant_id = client_id[11:len(client_id)]
+            
+        return tenant_id
+    else:
+        return None
+
+#
+def ensure_api_path(host: str):
+    
+    """
+    Adds /core/v3 or /v2 to host
+
+    :param host:   The host string.
+    :type host:    str
+    :returns:      The host string with path added.
+    :rtype:        str
+    """ 
+    
+    result = str(strip_slash(host))
+    
+    if ("pairs.res.ibm.com" in result):
+        if ("v2" not in result):
+            result = result + "/v2"
+    elif ("api.ibm.com" in result):
+        
+        if (result.endswith("api.ibm.com")):
+            result = result + "/geospatial/run/na"
+        elif (result.endswith("api.ibm.com/geospatial")):
+            result = result + "/run/na"
+        elif (result.endswith("api.ibm.com/geospatial/run")):
+            result = result + "/na"
+            
+        if ("core/v3" not in result):
+            if (result.endswith("core")):
+                result = result + "/v3"
+            else:
+                result = result + "/core/v3"
+                
+    return result
+
+#
+def strip_api_path(host: str):
+    
+    """
+    Removes core/v3 and /v2 from a string.
+
+    :param host:   The host string.
+    :type host:    str
+    :returns:      The host string with the path.
+    :rtype:        str
+    """
+
+    result = str(host)
+    
+    if (result.endswith("/core/v3")):
+        result = result[:-8]
+    elif host.endswith('/v2'):
+        result = result[:-3]
+
+    return result 
