@@ -12,7 +12,7 @@ import os
 # Dict corresponding to https://docs.python.org/3/library/logging.config.html#logging-config-dictschema
 LOGGING = {
     'version': 1,
-    'disable_existing_loggers': True,
+    'disable_existing_loggers': False,
     'formatters': {
         'standard': {
             'format': os.getenv('PAW_LOG_MSG_FORMAT', '%(asctime)s - %(name)s - %(levelname)s - %(message)s'),
