@@ -19,13 +19,23 @@ ERROR_AUTHENTICATION_FAILED = 'AUTHENTICATION FAILED: A {} could not be gathered
 ERROR_AUTHENTICATION_COULD_NOT_FIND_API_KEY_FILE = 'The api key file \'{}\' could not be found.'
 ERROR_AUTHENTICATION_NO_API_KEY_OR_CLIENT_ID = 'The OAuth2 Authentication type requires an api_key and client_id to be set.'
 ERROR_AUTHENTICATION_NO_REFRESH_TOKEN_OR_CLIENT_ID = 'The OAuth2 Authentication refresh_auth_token() call requires a oauth2_response.refresh_token and client_id to be set. The method is intended to be called once a user has already authenticated but the jwt token has expired, try executing the get_auth_token() method.'
-ERROR_AUTHENTICATION_PHOENIX_RETURN_NOT_OAUTH2RETURN = 'The json returned by the {} service was not of type OAuth2Return. The returned json is: \'{}\', the exception: \'{}\''
-ERROR_AUTHENTICATION_PHOENIX_NOT_SUCCESSFUL = 'The call to the {} service was not successful, the status code is: \'{}\''
-ERROR_AUTHENTICATION_PHOENIX_200_RETURN_ERROR = 'The call to the {} service was successful but produced an error \'{}\', perhaps the api_key value is incorrect.'
-ERROR_AUTHENTICATION_PHOENIX_REFRESH_200_RETURN_ERROR = 'The call to the {} service was successful but produced an error \'{}\', perhaps the refresh_token value is incorrect or a temporary issue with the authentication system prevented the procurement of an authentication token.'
+ERROR_AUTHENTICATION_RETURN_NOT_OAUTH2RETURN = 'The json returned by the {} service was not of type OAuth2Return. The returned json is: \'{}\', the exception: \'{}\''
+ERROR_AUTHENTICATION_NOT_SUCCESSFUL = 'The call to the {} service was not successful, the status code is: \'{}\''
+ERROR_AUTHENTICATION_NOT_SUCCESSFUL_API_CONNECT = 'The call to the {} service was not successful, the status code is: \'{}\', message: \'{}\''
+ERROR_AUTHENTICATION_200_RETURN_ERROR = 'The call to the {} service was successful but produced an error \'{}\', perhaps the api_key value is incorrect.'
+ERROR_AUTHENTICATION_REFRESH_200_RETURN_ERROR = 'The call to the {} service was successful but produced an error \'{}\', perhaps the refresh_token value is incorrect or a temporary issue with the authentication system prevented the procurement of an authentication token.'
 INFO_AUTHENTICATION_TOKEN_REFRESH = 'Attempting to refresh authentication token.'
 INFO_AUTHENTICATION_TOKEN_REFRESH_SUCCESS = 'The token was successfully refreshed.'
 ERROR_AUTHENTICATION_TYPE_NOT_RECOGNIZED = 'The authentication type {} was not recognized.'
+ERROR_AUTHENTICATION_IAM_NO_API_KEY_OR_CLIENT_ID = 'The OAuth2 Authentication type, when using API Connect, requires an api_key, client_id and org_id to be set.'
+ERROR_AUTHENTICATION_NO_ACCESS_TOKEN = 'An access_token from {} the return could not be found, response \'{}\'.'
+INFO_BOTH_CLIENT_ID_AND_TENANT_ID = 'The client_id {} and the tenant_id {} have both been specified; the tenant_id entry will be derived from client_id.'
+ERROR_NO_CLIENT_OR_TENANT_ID = 'A client_id or tenant_id must be specified in order to authentication via IBM API Connect.'
+ERROR_NO_ORG_ID = 'An org_id must be specified in order to authentication via IBM API Connect.'
+INFO_STARTS_WITH_GEOSPATIAL = 'The string starts with geospatial, where it should start with saascore; correcting.'
+INFO_STARTS_WITH_SAASCORE = 'The string starts with saascore, where it should start with geospatial; correcting.'
+INFO_API_CONNECT_POSSIBLE_TENANT_ID_IN_CLIENT_ID_FIELD = 'It might be that a tenant_id is declared in the client_id field, attempting to auth with \'saascore-\' prefixed.'
+INFO_AUTHENTICATION_SUCCESSFUL = 'Authentication success.'
 
 # catalog messages
 ERROR_CATALOG_RESPOSE_NOT_SUCCESSFUL = 'The {} {} call to {} failed with status code: {}, message: {}.'
@@ -98,6 +108,8 @@ DEBUG_CLIENT_SET_HEADERS = 'The headers for the client set to {}.'
 DEBUG_CLIENT_SET_AUTHENTICATION = 'The authentication for the client was set to {}.'
 
 ERROR_CLIENT_UNSPECIFIED_ERROR = 'The {} {} to {} encountered an unspecified error contacting the server; the request was unsuccessful, error message: {}'
+INFO_BASIC_AUTH_ASSUMPTION = 'The client authentication method is assumed to be Basic auth as password, or password file was specified.'
+INFO_0AUTH2_AUTH_ASSUMPTION = 'The client authentication method is assumed to be OAuth2.'
 
 # common messages
 INFO_COMMON_CHECK_BOOL_CONVERSION = 'The \'{}\' value \'{}\' was converted to a boolean \'{}\'.'
@@ -170,7 +182,7 @@ ERROR_QUERY_MERGE_UNAUTHORIZED = 'Unauthorized: The user may not be the owner of
 ERROR_QUERY_MERGE_NOT_FOUND = 'Not Found: It may be that one, or both, of the jobs (master and other) have failed.'
 ERROR_QUERY_MERGE_PRECONDITION = 'Precondition Failed: It may be that the master and other jobs have different bounding boxes.'
 ERROR_QUERY_JOB_LIST_UNKNOWN = 'The QueryJobList from_dict method only takes a dict or list, the type \'{}\' is not accepted.'
-INFO_STARTING_EVENT_LOOP = 'No running async even loop detected; performing asyncio.run() to start a new event loop.'
+INFO_STARTING_EVENT_LOOP = 'No running async event loop detected; performing asyncio.run() to start a new event loop.'
 DEBUG_FOUND_EVENT_LOOP = 'An already running async event loop was found; starting event loop in new thread.'
 INFO_FOUND_EVENT_LOOP_STARTING_TASK = 'TASK: {} STARTING.'
 INFO_FOUND_EVENT_LOOP_COMPLETED_TASK = 'TASK: {} COMPLETED.'
@@ -184,6 +196,15 @@ ERROR_QUERY_LATEST_QUERIES_TYPE_UNKNOWN = 'The latest_queries list can only be s
 WARN_QUERY_LATEST_QUERIES_QUERY_OBJECT_NO_NAME = 'A query in the latest_queries object has no name and therefore cannot be searched.'
 ERROR_QUERY_COULD_NOT_LOAD_POINT_QUERY = 'Unable to load point data into dataframe: {}.'
 ERROR_QUERY_NO_POINT_DATA = 'There is no point data in the Query object at Query.submit_response.data available to load/return.'
+ERROR_QUERY_NO_AOI_ID = 'The AOI object has no ID set and none was provided.'
+ERROR_QUERY_NO_GEOJSON = 'Sorry, the GeoJSON Python module (e.g. via `pip install geojson`) is required for AOI.get() to operate. Please install and try again.'
+WARN_QUERY_AOI_OBJECT_NO_ID = 'An AOI in the AOIs object has no id and therefore cannot be searched.'
+ERROR_QUERY_AOI_NO_AOI = 'The aois attribute does not contain an AOI with the id attribute {}.'
+ERROR_QUERY_AOI_MULTIPLE_IDENTICAL_IDS = 'The aois object has multiple properties with the id \'{}\'- this id should be unique.'
+ERROR_QUERY_AOI_ID_TYPE_UNKNOWN = 'The aois list can only be searched by an int id no, not {}.'
+ERROR_QUERY_AOI_UNKNOWN = 'The AOIs.from_dict() method only takes a dict or list, the type {} is not accepted.'
+ERROR_QUERY_AOI_RESPOSE_NOT_SUCCESSFUL = 'The {} {} call to {} failed with status code: {}, message: {}.'
+WARN_QUERY_INTERACTIVE_ALREADY_PERFORMED = 'The query.submit_response object has a data value already present; skipping action as it appears this is an online query and the gathering of data has already been performed.'
 
 # woc messages
 ERROR_QUERY_TYPE_NOT_RECOGNIZED = 'The query input type {} is not recognized, should be in [\'query.Query\',\'dict\',\'str\']'
